==> adamoracle-operator-ui-0.1.0.tgz: package/webpack.config.js <==
/* eslint-disable @typescript-eslint/no-var-requires */

const path = require('path')
const HtmlWebpackPlugin = require('html-webpack-plugin')
const { CleanWebpackPlugin } = require('clean-webpack-plugin')
const { EnvironmentPlugin } = require('webpack')
const TsconfigPathsPlugin = require('tsconfig-paths-webpack-plugin')
const dotenv = require("dotenv")

dotenv.config()

console.log('process.env::', process.env)
const isDev = process.env.NODE_ENV === 'development'
const extensions = ['.js', '.ts', '.tsx']

console.log('isDev::', isDev)

module.exports = {
  mode: isDev ? 'development' : 'production',
  entry: path.resolve(__dirname, 'src/index.js'),
  module: {
    rules: [
      {
        test: /\.js$/,
        exclude: /node_modules/,
        use: 'babel-loader',
      },
      {
        test: /\.tsx?$/,
        exclude: /node_modules/,
        use: 'babel-loader',
      },
      {
        test: /\.css$/i,
        use: ['style-loader', 'css-loader'],
      },
      {
        test: /\.svg$/i,
        use: 'file-loader',
      },
      {
        test: /\.png|.jpg$/i,
        use: 'file-loader',
      },
    ],
  },
  resolve: {
    extensions,
    plugins: [
      new TsconfigPathsPlugin({
        extensions,
      }),
    ],
  },
  output: {
    filename: '[name].[hash].js',
    path: path.resolve(__dirname, 'dist'),
    publicPath: '/',
  },
  plugins: [
    new CleanWebpackPlugin(),
    new HtmlWebpackPlugin({
      template: path.resolve(__dirname, 'src/index.html'),
    }),
    new EnvironmentPlugin({
      ADAMoracle_VERSION: process.env.ADAMoracle_VERSION,
      ADAMoracle_BASEURL: process.env.ADAMoracle_BASEURL,
    }),
  ],
  devtool: isDev ? 'source-map' : 'source-map',
  devServer: {
    port: 3000,
    contentBase: './dist',
    historyApiFallback: true,
    hot: true,
    proxy: {
      "/proxy": {
          target: "process.env.CHAINLINK_BASEURL", 
          // 因为使用的是https，会有协议安全校验，所以设置secure为false
          // port: ,
          ingorePath: true, // 默认即为 false, 注释掉也可以
          // ingorePath: false, 
          // changeOrigin是关键，如果不加这个就无法跳转请求，会产生跨域请求的问题
          changeOrigin: true,
          cookieDomainRewrite: "localhost",
          pathRewrite: {
          '^/proxy': ''//一般不会重写
        }
      },
    }
  },
}

==> adamoracle-operator-ui-0.1.3.tgz: package/webpack.config.js <==
/* eslint-disable @typescript-eslint/no-var-requires */

const path = require('path')
const HtmlWebpackPlugin = require('html-webpack-plugin')
const { CleanWebpackPlugin } = require('clean-webpack-plugin')
const { EnvironmentPlugin } = require('webpack')
const TsconfigPathsPlugin = require('tsconfig-paths-webpack-plugin')
const dotenv = require("dotenv")

dotenv.config()

console.log('process.env::', process.env)
const isDev = process.env.NODE_ENV === 'development'
const extensions = ['.js', '.ts', '.tsx']

console.log('isDev::', isDev)

module.exports = {
  mode: isDev ? 'development' : 'production',
  entry: path.resolve(__dirname, 'src/index.js'),
  module: {
    rules: [
      {
        test: /\.js$/,
        exclude: /node_modules/,
        use: 'babel-loader',
      },
      {
        test: /\.tsx?$/,
        exclude: /node_modules/,
        use: 'babel-loader',
      },
      {
        test: /\.css$/i,
        use: ['style-loader', 'css-loader'],
      },
      {
        test: /\.svg$/i,
        use: 'file-loader',
      },
      {
        test: /\.png|.jpg$/i,
        use: 'file-loader',
      },
    ],
  },
  resolve: {
    extensions,
    plugins: [
      new TsconfigPathsPlugin({
        extensions,
      }),
    ],
  },
  output: {
    filename: '[name].[hash].js',
    path: path.resolve(__dirname, 'dist'),
    publicPath: '/',
  },
  plugins: [
    new CleanWebpackPlugin(),
    new HtmlWebpackPlugin({
      template: path.resolve(__dirname, 'src/index.html'),
    }),
    new EnvironmentPlugin({
      ADAMoracle_VERSION: process.env.ADAMoracle_VERSION,
      ADAMoracle_BASEURL: process.env.ADAMoracle_BASEURL,
    }),
  ],
  devtool: isDev ? 'source-map' : 'source-map',
  devServer: {
    port: 3000,
    contentBase: './dist',
    historyApiFallback: true,
    hot: true,
    proxy: {
      "/proxy": {
          target: "process.env.ADAMoracle_BASEURL", 
          // 因为使用的是https，会有协议安全校验，所以设置secure为false
          // port: ,
          ingorePath: true, // 默认即为 false, 注释掉也可以
          // ingorePath: false, 
          // changeOrigin是关键，如果不加这个就无法跳转请求，会产生跨域请求的问题
          changeOrigin: true,
          cookieDomainRewrite: "localhost",
          pathRewrite: {
          '^/proxy': ''//一般不会重写
        }
      },
    }
  },
}
